This module provides an implementation of the PAMM methodology that is discussed in the papers that are cited below.
It also provides methods for using PAMM to determine how many hydrogen bonds each of the atoms in the system participate within.
These methods for determining which atoms are hydrogen bonded use the functionality from the [adjmat](module_adjmat.md) module 
and thus allow you to calculate an matrix in which element $i,j$ tells you if there is a hydrogen bond between atom $i$ and atom $j$.
